@@ -2,8 +2,8 @@
 #
 # SPDX-License-Identifier: MPL-2.0
 """This module contains all functions for generating figures."""
-from typing import List, Union
 import base64
+from typing import Union
 
 import pandas as pd
 import plotly.express as px
@@ -47,10 +47,10 @@ def plot_feature_importance(feature_importance: pd.DataFrame) -> go.Figure:
 
 
 def plot_data_series(
-    data: Union[List[pd.DataFrame], List[pd.Series]],
-    predict_data: Union[List[pd.DataFrame], List[pd.Series]] = None,
+    data: Union[list[pd.DataFrame], list[pd.Series]],
+    predict_data: Union[list[pd.DataFrame], list[pd.Series]] = None,
     horizon: int = 47,
-    names: List[str] = None,
+    names: list[str] = None,
 ) -> go.Figure:
     """Plots passed data and optionally prediction data for specified horizon.
 
@@ -123,7 +123,7 @@ def plot_data_series(
     return fig
 
 
-def _plot_data(names: List[str], series: List[pd.Series]) -> go.Figure:
+def _plot_data(names: list[str], series: list[pd.Series]) -> go.Figure:
     """Create plot of data consisting of different splits.
 
     Note:
@@ -167,7 +167,7 @@ def _plot_data(names: List[str], series: List[pd.Series]) -> go.Figure:
 
 
 def _plot_data_and_predictions(
-    names: List[str], actuals: List[pd.Series], predictions: List[pd.Series]
+    names: list[str], actuals: list[pd.Series], predictions: list[pd.Series]
 ) -> go.Figure:
     """Create plot of different data and prediction splits.
 
