@@ -57,8 +57,8 @@ def optimize_hyperparameters_task(
         return
 
     # Retrieve the paths for storing model and reports from the config manager
-    mlflow_tracking_uri = context.config.paths.mlflow_tracking_uri
-    artifact_folder = context.config.paths.artifact_folder
+    mlflow_tracking_uri = context.config.paths_mlflow_tracking_uri
+    artifact_folder = context.config.paths_artifact_folder
 
     # Determine if we need to optimize hyperparams
     # retrieve last model age where hyperparameters were optimized
@@ -107,7 +107,7 @@ def main(config=None, database=None):
 
     if database is None or config is None:
         raise RuntimeError(
-            "Please specify a configmanager and/or database connection object. These"
+            "Please specify a config object and/or database connection object. These"
             " can be found in the openstef-dbc package."
         )
 
